@@ -19,13 +19,6 @@ qx.Class.define("callbackery.ui.plugin.Html", {
         this.base(arguments);
         this._cfg = cfg;
         this._getParentFormData = getParentFormData;
-        this.setLayout(new qx.ui.layout.VBox(30));
-        var html = this._html = new qx.ui.embed.Html().set({
-            overflowX: "auto",
-            overflowY: "auto",
-            nativeContextMenu: true
-        });
-        this.add(html,{flex: 1});
         this.addListener('appear',this._loadData,this);
     },
     events: {
@@ -35,6 +28,18 @@ qx.Class.define("callbackery.ui.plugin.Html", {
         _cfg: null,
         _getParentFormData: null,
         _html: null,
+	_populate: function(){
+            this.setLayout(new qx.ui.layout.VBox(30));
+	    this.add(this._createHtml());
+	},
+	_createHtml: function(){
+            var html = this._html = new qx.ui.embed.Html().set({
+		overflowX: "auto",
+		overflowY: "auto",
+		nativeContextMenu: true
+            });
+	    return html;
+	},
         _loadData: function(){
             var html = this._html;
             var cfg = this._cfg;
